require 'lib/screen'
require 'lib/state_machine'
require 'lib/camera'
require 'lib/menu'
require 'lib/entities'

require 'src/states/title'
require 'src/objects/background'
require 'src/states/ready'
require 'src/states/play'

function love.load()
  love.graphics.setBackgroundColor(40/255, 10/255, 50/255)
  -- Don't blur images when zoomed in/out
  love.graphics.setDefaultFilter('nearest', 'nearest')
  
  love.mouse.setVisible(false)

  -- Force Resolution No Matter the Window Size
  screen.set(320,224) -- Sega Genesis Resolution

  -- Volume
  if love.filesystem.getInfo('volume.cfg') then
    local vol = love.filesystem.read('volume.cfg')
    vol = tonumber(vol)
    love.audio.setVolume(vol/100)
  else
    love.audio.setVolume(1)
  end

  -- Music
  intro = love.audio.newSource('sfx/intro.ogg', 'stream') intro:setLooping(true)
  music = love.audio.newSource('sfx/theme.ogg', 'stream') music:setLooping(true)

  -- Fonts
  g_bigfont = love.graphics.newFont('font/charybdis.ttf', 35, 'mono')
  g_menufont = love.graphics.newFont('font/charybdis.ttf',16, 'light')
  g_font = love.graphics.newFont('font/charybdis.ttf', 16, 'mono')
  -- My main.lua is heavily tied to state_machine
  state_machine.push(state_title, vars)
end

function love.update(dt)
  state_machine.update(dt)
end
function love.draw()
  -- Forced Resolution Draw
  screen.draw()

  -- Put universal draws here
  
  -- State Machine
  state_machine.draw()
end

-- Keyboard Inputs
function love.keypressed(key)
  state_machine.keypressed(key)
end
function love.keyreleased(key)
  state_machine.keyreleased(key)
end
function love.textinput(t)
  state_machine.textinput(t)
end

-- Mouse Functions
function love.mousemoved(x, y, dx, dy)
  state_machine.mousemoved(screen.convertX(x), screen.convertY(y), dx, dy)
end
function love.mousepressed(x, y, button)
  state_machine.mousepressed(screen.convertX(x), screen.convertY(y), button)
end
function love.mousereleased(x, y, button)
  state_machine.mousereleased(screen.convertX(x), screen.convertY(y), button)
end
function love.wheelmoved(x, y)
  state_machine.wheelmoved(x, y)
end

-- Window Functions
function love.resize(w, h)
  screen.resize(w, h)
end
