local Tiles = require 'lib/tile_manager'
local floor_spawncounter = 3
local floor_spawntick = 0
local previous_gap = 0
local drill = love.audio.newSource('sfx/drill.ogg', 'static')

level = {
  tile_size = 16,
  tile_map = {},
}
level.tiles = newTileSet(love.graphics.newImage('img/tiles.png'), level.tile_size)
walls = level.tiles.setDictionary({' 01', 'o|^'})

function level.load()
  level.tile_map = {}
  level.y = 0
  floor_spawntick = 1
  
  table.insert(level.tile_map, '^                  ^')
  for r = 2, 13 do
    table.insert(level.tile_map, '|                  |')
  end
  table.insert(level.tile_map, '|ooooooooooooooo  o|') -- First Floor
  table.insert(level.tile_map, '|                  |')

  level.tiles.loadMap(level.tile_map)
  level.tiles.update(0, 0)
end

function level.draw()
  level.tiles.draw()
end

function level.spawnFloor()
  local spawnx = 0
  local spawny = 0
  table.remove(level.tile_map, 1)
  local row = '|'
  floor_spawntick = floor_spawntick + 1
  
  if floor_spawntick%floor_spawncounter == 0 then
    floor_spawntick = 0

    local gap = 0
    repeat -- Don't create holes on the same spot
      gap = love.math.random(2, 18)
    until gap ~= previous_gap

    previous_gap = gap

    for c = 2, 18 do
      row = c == gap and row .. '  ' or row .. 'o'
    end
  else
    for i = 1, 18 do
      row = row .. ' '
    end
  end
  row = row .. '|'
  table.insert(level.tile_map, row)
  level.tiles.update(0,0)
  
  if floor_spawntick == 2 then
    _, spawnx, spawny = level.tiles.getTile(love.math.random(3,19),#level.tile_map+1)
  end
  return spawnx, spawny
end

function level.drillTiles(col, row)
  local c = col < 2 and 2 or col
        c = c > 18 and 18 or c
  local i = 1
  local new_floor = ''
  while i <= level.tile_map[row]:len() do
    if i == c or i == c + 1 then
      new_floor = new_floor .. ' '
    else
      new_floor = new_floor .. level.tile_map[row]:sub(i, i)
    end
    i = i + 1
  end
  level.tile_map[row] = new_floor
  level.tiles.update(0, 0)

  drill:play()
end
