local gravity = 25
local image = love.graphics.newImage('img/player.png')
image:setFilter('nearest', 'nearest')

player = newAnimatedEntity(image, 0, 0, 8)
player.speed = 150
player.jumpspeed = -355

player.addAnimation('idle',    0.35)  player.addFrames('idle',     0,  0, 16, 16, 2)
player.addAnimation('running', 0.065) player.addFrames('running',  0, 16, 16, 16, 6)
player.addAnimation('jumping', 0.15)  player.addFrames('jumping',  0, 32, 16, 16, 4)
player.addAnimation('falling', 0)     player.addFrames('falling', 32, 32, 16, 16, 1)
player.addAnimation('ability', 0.15)  player.addFrames('ability',  0, 32, 16, 16, 4)

function player.load(x, y)
  player.x = x
  player.y = y
  player.vy = 0
  player.vx = 0
  player.state = 'walking'
  
  player.jump = love.audio.newSource('sfx/jump.ogg', 'static')

  player.setAnimation('idle')
end

function player.inputs(dt)
  player.vx = 0
  
  if love.keyboard.isDown('left')  then player.vx = player.vx - player.speed end
  if love.keyboard.isDown('right') then player.vx = player.vx + player.speed end
  if love.keyboard.isDown('up') and player.state == 'walking' then
    player.vy = player.jumpspeed
    player.state = 'jumping'
    player.jump:stop()
    player.jump:play()
  end
end

function player.update(dt)
  -- Gravity-based Direction (Walking or Not)
  player.vy = player.state == 'walking' and 0 or player.vy + gravity

  -- Speed-based Direction (Left or Right)
  if player.vx < 0 then
    player.sx = -1
  elseif player.vx > 0 then
    player.sx = 1
  end
  player.move(player.vx * dt, player.vy * dt)
  
  -- State-based Animation
  if player.state == 'walking' then
    player.setAnimation(player.vx == 0 and 'idle' or 'running')
  elseif player.state == 'jumping' then
    player.setAnimation('jumping', false)
  elseif player.state == 'falling' then
    player.setAnimation('falling')
  end
end
