local img, y
local max_jackhammers = 5

-- Addition Indicator (The ones popping out with +N when picking up items)
local msg_font, messages
local msg_fadespeed = 70

ui = {}

function ui.load()
  img = love.graphics.newImage('img/jackhammer.png')
  ui.jackhammers = 3
  ui.score = 0
  ui.cooldown = 0
  y = -20

  messages = {}
  msg_font = love.graphics.newFont(7, 'mono')
end

function ui.update(dt)
  ui.cooldown = ui.cooldown <= 0 and 0 or ui.cooldown - dt
  
  for _, msg in pairs(messages) do
    msg.a = msg.a - msg_fadespeed * dt
    msg.y = msg.y - (camera.speed + 10) * dt
  end
  
  local message_deleter = {}
  for i = 1, #messages do
    if messages[i].a <= 0 or messages[i].y <= 0 then
      table.insert(message_deleter, i)
    end
  end
  
  for i = #message_deleter, 1, -1 do
    table.remove(messages, message_deleter[i])
  end
end

function ui.draw()
  love.graphics.setColor(1,1,1)
  love.graphics.setFont(g_font)
  
  -- Jack Hammer Icon
  love.graphics.draw(img, 16, y)

  -- Cooldown Display
  love.graphics.setColor(25/255,25/255,25/255,0.65)
  local height = (ui.cooldown / 2) * img:getHeight()
  love.graphics.rectangle('fill', 16, 16 + img:getHeight() - height, img:getWidth(), height)
  love.graphics.rectangle('fill', (screen.width/2) - (g_font:getWidth(ui.score)/2) - 3, y, g_font:getWidth(ui.score) + 6, 16, 2, 2)

  -- Jack Hammer Charges
  for i = 1, max_jackhammers do
    love.graphics.setColor(i > ui.jackhammers and {0, 80/255, 120/255} or {30/255, 180/255, 220/255})
    love.graphics.rectangle('fill', 32 + (i-1) * 7, y + 4, 6, 8)
    love.graphics.setColor(250/255, 175/255, 0)
    love.graphics.rectangle('line', 32 + (i-1) * 7, y + 4, 6, 8, 1, 1)
  end

  -- Score
  love.graphics.setColor(1,1,1)
  love.graphics.rectangle('line', (screen.width/2) - (g_font:getWidth(ui.score)/2) - 3, y, g_font:getWidth(ui.score) + 6, 16, 2, 2)
  love.graphics.printf(ui.score, 0, y, screen.width, 'center')
  
  -- Messages
  love.graphics.setFont(msg_font)
  for _, m in pairs(messages) do
    love.graphics.setColor(1,1,1,m.a/100)
    love.graphics.print(m.text, m.x, m.y)
  end
end

function ui.addJackHammer()
  ui.jackhammers = ui.jackhammers >= max_jackhammers and max_jackhammers or ui.jackhammers + 1
end

function ui.addMessage(msg, x, y)
  local text = '+' .. msg
  table.insert(messages, {text = text, x = x - (msg_font:getWidth(msg) / 2), y = y - camera.y, a = 100})
  ui.score = ui.score + msg
end

function ui.move(dy)
  y = y >= 16 and 16 or y + dy
end
