local TextInput = require 'lib/textinput'

local menu, minifont, level, laser_cannons, debris, highscores, score, highscorer, rank, text, bigcolor
local explode = love.audio.newSource('sfx/explode.ogg', 'static')

state_gameover = newState()

local function enterHighScore()
  if highscorer.active then
    if highscorer.text == '' then
      highscorer.text = 'Jack' .. love.math.random(1000)
    end
    
    for i = #highscores, rank, -1 do
      if i > 1 then
        highscores[i].name = highscores[i-1].name
        highscores[i].score = highscores[i-1].score
      end
    end
    highscores[rank].name = highscorer.text
    highscores[rank].score = score

    local list = ''
    for i = 1, 10 do
      local name  = highscores[i].name
      local score = highscores[i].score
      list = list .. name .. ' ' .. score .. '\n'
    end
    love.filesystem.write('highscores.lst', list)
  end
end

function state_gameover.load(vars)
  minifont = love.graphics.newFont('font/charybdis.ttf', 16, 'mono')
  text = 'Game Over'
  bigcolor = {1,50/255,50/255}
  score = vars.score
  level = vars.level
  laser_cannons = vars.laser_cannons
  for _, lc in pairs(laser_cannons) do lc.sy = -1 end
  debris = vars.debris

  highscorer = newTextInput(love.graphics.newFont(12, 'mono'), (screen.width/3), 40, 18)
  highscores = {}
  for jacks in love.filesystem.lines('highscores.lst') do
    local info = {}
    for data in jacks:gmatch('%S+') do
      table.insert(info, data)
    end
    table.insert(highscores, {name = info[1], score = tonumber(info[2])})
  end
  
  highscorer.active = false
  local i = 1
  local achieved = false
  repeat
    achieved = score > highscores[i].score
    i = i + 1
  until i > #highscores or achieved == true
  
  if achieved == true then
    highscorer.active = true
    rank = i - 1
    text = 'High Score'
    bigcolor = {1,1,50/255}
  end

  menu = newMenu(g_menufont, 2, {roundx = 2, roundy = 2})
  menu.addButton('Play Again',   (screen.width/2), 115, function() enterHighScore() state_machine.change(state_ready) end)
  menu.addButton('Title Screen', (screen.width/2), 140, function() enterHighScore() state_machine.change(state_title) end)
  menu.addButton('Quit'  ,       (screen.width/2), 165, function() enterHighScore() love.event.quit()                 end)
  menu.selected_index = 1

  explode:play()
end

function state_gameover.update(dt)
  for i, lc in ipairs(laser_cannons) do
    lc.updateAnimation(dt)
    lc.move(0, -30 * dt)
    if lc.y + level.tile_size < 0 then
      table.remove(laser_cannons, i)
    end
  end
  debris:update(dt)
  highscorer.update(dt)
end

function state_gameover.draw()
  background.draw()
  camera.set()
    level.draw()
  camera.unset()
  for _, lc in pairs(laser_cannons) do lc.draw() end

  love.graphics.draw(debris)

  love.graphics.setColor(0, 0, 0, 0.2)
  love.graphics.rectangle('fill', 0, 0, screen.width, screen.height)

  love.graphics.setColor(1,1,1)
  love.graphics.setFont(g_font)
  love.graphics.printf(score, 0, 16, screen.width, 'center')
  
  love.graphics.setFont(g_bigfont)
  love.graphics.setColor(bigcolor)
  love.graphics.printf(text, 0, 55, screen.width, 'center')
  
  highscorer.draw()
  menu.draw()
end

function state_gameover.keypressed(key)
  if key == 'return' then
    menu.button_press()
  elseif key == 'right' or key == 'down' then
    menu.cycle_down()
  elseif key == 'left' or key == 'up' then
    menu.cycle_up()
  else
    highscorer.keypressed(key)
  end
end
function state_gameover.keyreleased(key)
  if key == 'return' then
    menu.button_release()
  end
end
function state_gameover.textinput(t)
  if t ~= ' ' then highscorer.textinput(t) end
end
