local Level       = require 'src/objects/level'
local Player      = require 'src/objects/player'
local LaserCannon = require 'src/objects/laser_cannon'
local UI          = require 'src/objects/ui'

local alarm          = love.audio.newSource('sfx/alarm.ogg', 'static')
local deploy_cannons = love.audio.newSource('sfx/deploy_cannons.ogg', 'static')

local laser_cannons, status, rotation, player_look_time
local rotation_speed = 100
local player_look_speed = 0.33

state_ready = newState()

function state_ready.load()
  background.load()
  intro:stop()
  level.load()
  player.load(screen.width/2, 0)
  player.setAnimation('falling')
  player.state = 'falling'
  player.sx = -1
  laser_cannons = {}
  
  local _, x1, y1 = level.tiles.getTile(1,1)
  local _, x2, y2 = level.tiles.getTile(math.floor(screen.width/level.tile_size),math.floor(screen.height/level.tile_size))
  x1 = x1 + level.tile_size / 2
  y1 = y1 + level.tile_size / 2
  x2 = x2 + level.tile_size / 2
  y2 = y2 + level.tile_size / 2

  table.insert(laser_cannons, newLaserCannon(x1, y1))
  table.insert(laser_cannons, newLaserCannon(x2, y1)) laser_cannons[2].sx = -1
  table.insert(laser_cannons, newLaserCannon(x1, y2))
  table.insert(laser_cannons, newLaserCannon(x2, y2)) laser_cannons[4].sx = -1

  status = 'safe'
  rotation = 180
  player_look_time = 0
  
  for _, v in pairs(laser_cannons) do
    v.setRotation(rotation)
  end
  
  ui.load()
end

function state_ready.update(dt)
  -- Player: Falling Collision
  local l, x, y = level.tiles.getTile(math.ceil(player.x/level.tile_size), math.floor(player.y/level.tile_size))
  l, x, y = level.tiles.getTile(math.ceil(player.x/level.tile_size), math.ceil(player.y/level.tile_size)+1)
  if l > 0 then
    player.state = 'walking'
    player.y = y - player.radius
    player.vy = 0
    status = 'danger'
  end

  player.update(dt)
  player.updateAnimation(dt)
  
  if status == 'danger' and rotation > 0 then
    alarm:play()
    rotation = rotation <= 0 and 0 or rotation - rotation_speed * dt
    for _, v in pairs(laser_cannons) do
      v.setRotation(rotation)
      if rotation <= 0 then v.setAnimation('deploy', false) end
    end
    
    player_look_time = player_look_time + dt
    if player_look_time >= player_look_speed then
      player_look_time = player_look_time - player_look_speed
      player.sx = -player.sx
    end
    
    ui.move(50 * dt)
  end

  if rotation <= 0 then
    alarm:stop()
    deploy_cannons:play()
  end
  
  for _, v in pairs(laser_cannons) do
    v.updateAnimation(dt)
  end
  
  if laser_cannons[1].animation_playing == false then
    state_machine.change(state_play, {level = level, player = player, laser_cannons = laser_cannons, ui = ui})
  end
end
function state_ready.draw()
  background.draw()
  level.draw()
  player.draw()
  for _, v in pairs(laser_cannons) do
    v.draw()
  end
  
  ui.draw()
end
