local menu, bigfont, font, option, volume, window
local windows = {
  { w =  640, h = 448, fullscreen = false},
  { w =  960, h = 672, fullscreen = false},
  { w = 1280, h = 896, fullscreen = false},
  { w = 320,  h = 896, fullscreen = true}
}

local function saveExit()
  love.filesystem.write('screen.cfg',
    windows[window].w .. '\n' ..
    windows[window].h .. '\n' ..
    tostring(windows[window].fullscreen)
  )
  love.filesystem.write('volume.cfg', volume)
  state_machine.change(state_title)
end

state_settings = newState()

function state_settings.load()
  titlefont = love.graphics.newFont('font/charybdis.ttf', 34, 'mono')
  bigfont = love.graphics.newFont('font/charybdis.ttf', 16, 'mono')
  font = love.graphics.newFont(12, 'mono')
  
  if love.window.getFullscreen() == true then
    window = 4
  else
    local data = {}
    for line in love.filesystem.lines('screen.cfg') do
      table.insert(data, line)
    end
    
    for i = 1, #windows do
      if windows[i].w == tonumber(data[1]) then
        window = i
      end
    end
  end

  if love.filesystem.getInfo('volume.cfg') then
    local vol = love.filesystem.read('volume.cfg')
    volume = tonumber(vol)
  else
    volume = 100
  end
  love.audio.setVolume(volume/100)

  menu = newMenu(g_menufont, 2, {roundx = 2, roundy = 2})
  menu.addButton('Back', screen.width / 2, screen.height - 20, function() saveExit() end)

  option = 1
end

function state_settings.draw()
  love.graphics.setFont(g_bigfont)
  love.graphics.printf('Settings', 0, 0, screen.width, 'center')

  love.graphics.setFont(bigfont)
  if option == 1 then love.graphics.setColor(1,1,0) else love.graphics.setColor(1,1,1) end
  love.graphics.printf('Window', 0,  50, screen.width, 'center')
  love.graphics.setFont(font)
  local text = window == 4 and 'Fullscreen' or windows[window].w .. 'x' .. windows[window].h
  love.graphics.printf(text, 0, 70, screen.width, 'center')
  love.graphics.printf(option == 1 and '<-                  ->' or '', 0, 70, screen.width, 'center')

  love.graphics.setFont(bigfont)
  if option == 2 then love.graphics.setColor(1,1,0) else love.graphics.setColor(1,1,1) end
  love.graphics.printf('Volume', 0, 130, screen.width, 'center')
  for i = 1, 10 do
    if i * 10 <= volume then love.graphics.setColor(10/255,90/255,10/255) else love.graphics.setColor(0,0,0) end
    love.graphics.rectangle('fill', 90 + ((i-1) * 14), 155, 12, 20)
    love.graphics.setColor(200/255,200/255,200/255)
    love.graphics.rectangle('line', 90 + ((i-1) * 14), 155, 12, 20,1 ,1)
  end
  menu.draw()
end

function state_settings.keypressed(key)
  if key == 'return' then
    menu.button_press()
  elseif key == 'escape' then
    saveExit()
  elseif key == 'up' then
    option = option == 1 and 3 or option - 1
  elseif key == 'down' then
    option = option == 3 and 1 or option + 1
  elseif key == 'left' then
    if option == 1 then
      window = window <= 1 and #windows or window - 1
      love.window.setMode(windows[window].w, windows[window].h, {fullscreen = windows[window].fullscreen})
      screen.resize(love.graphics.getWidth(), love.graphics.getHeight())
    elseif option == 2 then
      volume = volume <= 0 and 0 or volume - 10
    end
  elseif key == 'right' then
    if option == 1 then
      window = window >= #windows and 1 or window + 1
      love.window.setMode(windows[window].w, windows[window].h, {fullscreen = windows[window].fullscreen})
      screen.resize(love.graphics.getWidth(), love.graphics.getHeight())
    elseif option == 2 then
      volume = volume >= 100 and 100 or volume + 10
    end
  end

  love.audio.setVolume(volume/100)

  menu.selected_index = option == 3 and 1 or nil
end
function state_settings.keyreleased(key)
  if key == 'return' then menu.button_release() end
end
