local HighScores = require 'src/states/highscores'
local Settings   = require 'src/states/settings'
local img, menu, title_font

local psimg, ps

state_title = newState()

function state_title.load()
  img = love.graphics.newImage('img/title.png')
  title_font = love.graphics.newFont('font/charybdis.ttf', 65, 'mono')
  intro:play()
  menu = newMenu(g_menufont, 2, {roundx = 2, roundy = 2})
  menu.addButton('Play',        (screen.width/2), 115, function() state_machine.change(state_ready)      end)
  menu.addButton('Settings',    (screen.width/2), 140, function() state_machine.change(state_settings)   end)
  menu.addButton('High Scores', (screen.width/2), 165, function() state_machine.change(state_highscores) end)
  menu.addButton('Quit'  ,      (screen.width/2), 190, function() love.event.quit()                      end)
  menu.selected_index = 1
  
  -- If a High Score List doesn't exist, create it
  if not love.filesystem.getInfo('highscores.lst') then
    local list = ''
    for i = 10, 1, -1 do
      local name  = 'Jack' .. love.math.random(90)
      local score = i * 100
      list = list .. name .. ' ' .. score .. '\n'
    end
    love.filesystem.write('highscores.lst', list)
  end
  
  psimg = love.graphics.newImage('img/debris.png')
  ps = love.graphics.newParticleSystem(psimg, 6)
  ps:setEmitterLifetime(-1)
  ps:setQuads(love.graphics.newQuad(0, 0, 8, 8, psimg:getWidth(), psimg:getHeight()))
  ps:setEmissionRate(12)
  ps:setSizes(0.2)
  ps:setDirection(math.rad(-90))
  ps:setLinearAcceleration(0, 200)
  ps:setParticleLifetime(1.5)
  ps:setSpread(math.rad(40))
  ps:setSpeed(100)
  ps:setRelativeRotation(true)
  ps:setPosition(screen.width/2, 88)
end

function state_title.update(dt)
  ps:update(dt)
end

function state_title.draw()
  love.graphics.draw(img)
  love.graphics.draw(ps)
  love.graphics.setFont(title_font)
  love.graphics.printf('TOWER JACK', 0, 10, screen.width, 'center')
  menu.draw()
end

function state_title.keypressed(key)
  if     key == 'return' then menu.button_press()
  elseif key == 'up'     then menu.cycle_up()
  elseif key == 'down'   then menu.cycle_down()
  end
end

function state_title.keyreleased(key)
  if key == 'return' then menu.button_release() end
end
